==> zio-aws-braket_2.13-5.19.17.2-sources.jar: zio/aws/braket/model/package.scala <==
package zio.aws.braket
import zio.prelude.Subtype
import java.time.Instant
import zio.aws.braket.model.primitives.QuantumTaskArn.Type
import zio.aws.braket.model.primitives.{HyperParametersValueString, String256}
package object model {
  import scala.jdk.CollectionConverters._
  object primitives {
    object CreateJobRequestJobNameString extends Subtype[String]
    type CreateJobRequestJobNameString =
      zio.aws.braket.model.primitives.CreateJobRequestJobNameString.Type
    object CreateQuantumTaskRequestDeviceParametersString
        extends Subtype[String]
    type CreateQuantumTaskRequestDeviceParametersString =
      zio.aws.braket.model.primitives.CreateQuantumTaskRequestDeviceParametersString.Type
    object CreateQuantumTaskRequestOutputS3BucketString extends Subtype[String]
    type CreateQuantumTaskRequestOutputS3BucketString =
      zio.aws.braket.model.primitives.CreateQuantumTaskRequestOutputS3BucketString.Type
    object CreateQuantumTaskRequestOutputS3KeyPrefixString
        extends Subtype[String]
    type CreateQuantumTaskRequestOutputS3KeyPrefixString =
      zio.aws.braket.model.primitives.CreateQuantumTaskRequestOutputS3KeyPrefixString.Type
    object CreateQuantumTaskRequestShotsLong extends Subtype[Long]
    type CreateQuantumTaskRequestShotsLong =
      zio.aws.braket.model.primitives.CreateQuantumTaskRequestShotsLong.Type
    object DeviceArn extends Subtype[String]
    type DeviceArn = zio.aws.braket.model.primitives.DeviceArn.Type
    object GetJobResponseJobNameString extends Subtype[String]
    type GetJobResponseJobNameString =
      zio.aws.braket.model.primitives.GetJobResponseJobNameString.Type
    object HyperParametersValueString extends Subtype[String]
    type HyperParametersValueString =
      zio.aws.braket.model.primitives.HyperParametersValueString.Type
    object InputFileConfigChannelNameString extends Subtype[String]
    type InputFileConfigChannelNameString =
      zio.aws.braket.model.primitives.InputFileConfigChannelNameString.Type
    object InstanceConfigInstanceCountInteger extends Subtype[Int]
    type InstanceConfigInstanceCountInteger =
      zio.aws.braket.model.primitives.InstanceConfigInstanceCountInteger.Type
    object InstanceConfigVolumeSizeInGbInteger extends Subtype[Int]
    type InstanceConfigVolumeSizeInGbInteger =
      zio.aws.braket.model.primitives.InstanceConfigVolumeSizeInGbInteger.Type
    type Integer = Int
    object JobArn extends Subtype[String]
    type JobArn = zio.aws.braket.model.primitives.JobArn.Type
    object JobEventDetailsMessageString extends Subtype[String]
    type JobEventDetailsMessageString =
      zio.aws.braket.model.primitives.JobEventDetailsMessageString.Type
    object JobStoppingConditionMaxRuntimeInSecondsInteger extends Subtype[Int]
    type JobStoppingConditionMaxRuntimeInSecondsInteger =
      zio.aws.braket.model.primitives.JobStoppingConditionMaxRuntimeInSecondsInteger.Type
    object JobToken extends Subtype[String]
    type JobToken = zio.aws.braket.model.primitives.JobToken.Type
    object JsonValue extends Subtype[String]
    type JsonValue = zio.aws.braket.model.primitives.JsonValue.Type
    object QuantumTaskArn extends Subtype[String]
    type QuantumTaskArn = zio.aws.braket.model.primitives.QuantumTaskArn.Type
    object RoleArn extends Subtype[String]
    type RoleArn = zio.aws.braket.model.primitives.RoleArn.Type
    object S3Path extends Subtype[String]
    type S3Path = zio.aws.braket.model.primitives.S3Path.Type
    object SearchDevicesFilterNameString extends Subtype[String]
    type SearchDevicesFilterNameString =
      zio.aws.braket.model.primitives.SearchDevicesFilterNameString.Type
    object SearchDevicesRequestMaxResultsInteger extends Subtype[Int]
    type SearchDevicesRequestMaxResultsInteger =
      zio.aws.braket.model.primitives.SearchDevicesRequestMaxResultsInteger.Type
    object SearchJobsRequestMaxResultsInteger extends Subtype[Int]
    type SearchJobsRequestMaxResultsInteger =
      zio.aws.braket.model.primitives.SearchJobsRequestMaxResultsInteger.Type
    object SearchQuantumTasksRequestMaxResultsInteger extends Subtype[Int]
    type SearchQuantumTasksRequestMaxResultsInteger =
      zio.aws.braket.model.primitives.SearchQuantumTasksRequestMaxResultsInteger.Type
    object String1024 extends Subtype[String]
    type String1024 = zio.aws.braket.model.primitives.String1024.Type
    object String2048 extends Subtype[String]
    type String2048 = zio.aws.braket.model.primitives.String2048.Type
    object String256 extends Subtype[String]
    type String256 = zio.aws.braket.model.primitives.String256.Type
    object String4096 extends Subtype[String]
    type String4096 = zio.aws.braket.model.primitives.String4096.Type
    object String64 extends Subtype[String]
    type String64 = zio.aws.braket.model.primitives.String64.Type
    object SyntheticTimestamp_date_time extends Subtype[Instant]
    type SyntheticTimestamp_date_time =
      zio.aws.braket.model.primitives.SyntheticTimestamp_date_time.Type
    object Uri extends Subtype[String]
    type Uri = zio.aws.braket.model.primitives.Uri.Type
  }
  type CreateJobRequestInputDataConfigList =
    List[zio.aws.braket.model.InputFileConfig]
  type DeviceSummaryList = List[zio.aws.braket.model.DeviceSummary]
  type HyperParameters = Map[String256, HyperParametersValueString]
  type InputConfigList = List[zio.aws.braket.model.InputFileConfig]
  type JobEvents = List[zio.aws.braket.model.JobEventDetails]
  type JobSummaryList = List[zio.aws.braket.model.JobSummary]
  type QuantumTaskSummaryList = List[zio.aws.braket.model.QuantumTaskSummary]
  type SearchDevicesFilterValuesList = List[String256]
  type SearchDevicesRequestFiltersList =
    List[zio.aws.braket.model.SearchDevicesFilter]
  type SearchJobsFilterValuesList = List[String256]
  type SearchJobsRequestFiltersList =
    List[zio.aws.braket.model.SearchJobsFilter]
  type SearchQuantumTasksFilterValuesList = List[String256]
  type SearchQuantumTasksRequestFiltersList =
    List[zio.aws.braket.model.SearchQuantumTasksFilter]
  type TagKeys = List[String]
  type TagsMap = Map[String, String]
}

==> zio-aws-braket_3-5.17.127.1-sources.jar: zio/aws/braket/model/package.scala <==
package zio.aws.braket
import zio.prelude.Subtype
import java.time.Instant
import zio.aws.braket.model.primitives.QuantumTaskArn.Type
import zio.aws.braket.model.primitives.{HyperParametersValueString, String256}
package object model {
  import scala.jdk.CollectionConverters.*
  object primitives {
    object CreateJobRequestJobNameString extends Subtype[String]
    type CreateJobRequestJobNameString =
      zio.aws.braket.model.primitives.CreateJobRequestJobNameString.Type
    object CreateQuantumTaskRequestDeviceParametersString
        extends Subtype[String]
    type CreateQuantumTaskRequestDeviceParametersString =
      zio.aws.braket.model.primitives.CreateQuantumTaskRequestDeviceParametersString.Type
    object CreateQuantumTaskRequestOutputS3BucketString extends Subtype[String]
    type CreateQuantumTaskRequestOutputS3BucketString =
      zio.aws.braket.model.primitives.CreateQuantumTaskRequestOutputS3BucketString.Type
    object CreateQuantumTaskRequestOutputS3KeyPrefixString
        extends Subtype[String]
    type CreateQuantumTaskRequestOutputS3KeyPrefixString =
      zio.aws.braket.model.primitives.CreateQuantumTaskRequestOutputS3KeyPrefixString.Type
    object CreateQuantumTaskRequestShotsLong extends Subtype[Long]
    type CreateQuantumTaskRequestShotsLong =
      zio.aws.braket.model.primitives.CreateQuantumTaskRequestShotsLong.Type
    object DeviceArn extends Subtype[String]
    type DeviceArn = zio.aws.braket.model.primitives.DeviceArn.Type
    object GetJobResponseJobNameString extends Subtype[String]
    type GetJobResponseJobNameString =
      zio.aws.braket.model.primitives.GetJobResponseJobNameString.Type
    object HyperParametersValueString extends Subtype[String]
    type HyperParametersValueString =
      zio.aws.braket.model.primitives.HyperParametersValueString.Type
    object InputFileConfigChannelNameString extends Subtype[String]
    type InputFileConfigChannelNameString =
      zio.aws.braket.model.primitives.InputFileConfigChannelNameString.Type
    object InstanceConfigVolumeSizeInGbInteger extends Subtype[Int]
    type InstanceConfigVolumeSizeInGbInteger =
      zio.aws.braket.model.primitives.InstanceConfigVolumeSizeInGbInteger.Type
    object Integer extends Subtype[Int]
    type Integer = zio.aws.braket.model.primitives.Integer.Type
    object JobArn extends Subtype[String]
    type JobArn = zio.aws.braket.model.primitives.JobArn.Type
    object JobEventDetailsMessageString extends Subtype[String]
    type JobEventDetailsMessageString =
      zio.aws.braket.model.primitives.JobEventDetailsMessageString.Type
    object JobStoppingConditionMaxRuntimeInSecondsInteger extends Subtype[Int]
    type JobStoppingConditionMaxRuntimeInSecondsInteger =
      zio.aws.braket.model.primitives.JobStoppingConditionMaxRuntimeInSecondsInteger.Type
    object JobToken extends Subtype[String]
    type JobToken = zio.aws.braket.model.primitives.JobToken.Type
    object JsonValue extends Subtype[String]
    type JsonValue = zio.aws.braket.model.primitives.JsonValue.Type
    object QuantumTaskArn extends Subtype[String]
    type QuantumTaskArn = zio.aws.braket.model.primitives.QuantumTaskArn.Type
    object RoleArn extends Subtype[String]
    type RoleArn = zio.aws.braket.model.primitives.RoleArn.Type
    object S3Path extends Subtype[String]
    type S3Path = zio.aws.braket.model.primitives.S3Path.Type
    object SearchDevicesFilterNameString extends Subtype[String]
    type SearchDevicesFilterNameString =
      zio.aws.braket.model.primitives.SearchDevicesFilterNameString.Type
    object SearchDevicesRequestMaxResultsInteger extends Subtype[Int]
    type SearchDevicesRequestMaxResultsInteger =
      zio.aws.braket.model.primitives.SearchDevicesRequestMaxResultsInteger.Type
    object SearchJobsRequestMaxResultsInteger extends Subtype[Int]
    type SearchJobsRequestMaxResultsInteger =
      zio.aws.braket.model.primitives.SearchJobsRequestMaxResultsInteger.Type
    object SearchQuantumTasksRequestMaxResultsInteger extends Subtype[Int]
    type SearchQuantumTasksRequestMaxResultsInteger =
      zio.aws.braket.model.primitives.SearchQuantumTasksRequestMaxResultsInteger.Type
    object String1024 extends Subtype[String]
    type String1024 = zio.aws.braket.model.primitives.String1024.Type
    object String2048 extends Subtype[String]
    type String2048 = zio.aws.braket.model.primitives.String2048.Type
    object String256 extends Subtype[String]
    type String256 = zio.aws.braket.model.primitives.String256.Type
    object String4096 extends Subtype[String]
    type String4096 = zio.aws.braket.model.primitives.String4096.Type
    object String64 extends Subtype[String]
    type String64 = zio.aws.braket.model.primitives.String64.Type
    object SyntheticTimestamp_date_time extends Subtype[Instant]
    type SyntheticTimestamp_date_time =
      zio.aws.braket.model.primitives.SyntheticTimestamp_date_time.Type
    object Uri extends Subtype[String]
    type Uri = zio.aws.braket.model.primitives.Uri.Type
  }
  type CreateJobRequestInputDataConfigList =
    List[zio.aws.braket.model.InputFileConfig]
  type DeviceSummaryList = List[zio.aws.braket.model.DeviceSummary]
  type HyperParameters = Map[String256, HyperParametersValueString]
  type InputConfigList = List[zio.aws.braket.model.InputFileConfig]
  type JobEvents = List[zio.aws.braket.model.JobEventDetails]
  type JobSummaryList = List[zio.aws.braket.model.JobSummary]
  type QuantumTaskSummaryList = List[zio.aws.braket.model.QuantumTaskSummary]
  type SearchDevicesFilterValuesList = List[String256]
  type SearchDevicesRequestFiltersList =
    List[zio.aws.braket.model.SearchDevicesFilter]
  type SearchJobsFilterValuesList = List[String256]
  type SearchJobsRequestFiltersList =
    List[zio.aws.braket.model.SearchJobsFilter]
  type SearchQuantumTasksFilterValuesList = List[String256]
  type SearchQuantumTasksRequestFiltersList =
    List[zio.aws.braket.model.SearchQuantumTasksFilter]
  type TagKeys = List[String]
  type TagsMap = Map[String, String]
}
